@@ -6,7 +6,7 @@ class HentaiVnNet(Provider, Std):
     def get_chapter_index(self) -> str:
         return self.chapter_id
 
-    def get_main_content(self):
+    def get_content(self):
         return self.http().get(self.get_url())
 
     def get_manga_name(self) -> str:
