@@ -7,7 +7,7 @@ class MangaMexatCom(Provider, Std):
     def get_chapter_index(self) -> str:
         return self.chapter[1].replace('.', '-')
 
-    def get_main_content(self):
+    def get_content(self):
         return self._get_content('{}/category/{}/')
 
     def get_manga_name(self) -> str:
