@@ -9,7 +9,7 @@ class MangaInnNet(Provider, Std):
         idx = self.re.search(r'\.\w{2,7}/[^/]+/([^/]+)', chapter).group(1).split('.')
         return '{}-{}'.format(*self._idx_to_x2(idx))
 
-    def get_main_content(self):
+    def get_content(self):
         return self._get_content('{}/{}')
 
     def get_manga_name(self) -> str:
