@@ -10,7 +10,7 @@ class MyMangaListOrg(Provider, Std):
         re = self.re.compile(r'/download/[^/]+?(\d+)')
         return re.search(self.chapter).group(1)
 
-    def get_main_content(self):
+    def get_content(self):
         return self._get_content('{}/read-{}')
 
     def get_manga_name(self) -> str:
