@@ -12,7 +12,7 @@ class ReadMsNet(Provider, Std):
         idx = self.re.search('/r/[^/]+/[^/]+/([^/]+)', self.chapter)
         return idx.group(1)
 
-    def get_main_content(self):
+    def get_content(self):
         return self._get_content('{}/manga/{}')
 
     def get_manga_name(self) -> str:
