@@ -10,7 +10,7 @@ class ReMangaOrg(Provider, Std):
             *idx.groups()
         ).replace('.', '-')
 
-    def get_main_content(self):
+    def get_content(self):
         return self._get_content('{}/manga/{}')
 
     def get_manga_name(self) -> str:
